Documentation
¶
Index ¶
- Constants
- func CheckProviders(ctx context.Context, registry *providers.Registry, providerIDs []string, ...) (status.Response, error)
- func StreamProviders(ctx context.Context, registry *providers.Registry, providerIDs []string, ...) (<-chan ProviderStatusResult, error)
- type ProviderStatusResult
- type StatusOptions
Constants ¶
Variables ¶
This section is empty.
Functions ¶
func CheckProviders ¶
func CheckProviders(ctx context.Context, registry *providers.Registry, providerIDs []string, opts StatusOptions) (status.Response, error)
CheckProviders fetches all requested providers concurrently and returns results in the same order as the requested IDs.
func StreamProviders ¶ added in v1.0.1
func StreamProviders(ctx context.Context, registry *providers.Registry, providerIDs []string, opts StatusOptions) (<-chan ProviderStatusResult, error)
StreamProviders fetches requested providers concurrently and emits each provider snapshot as soon as it is available. A final Done result is emitted after cache persistence and aggregate error handling are complete.
Types ¶
Click to show internal directories.
Click to hide internal directories.